@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afstreams.c,v 1.4.2.4 1999/11/24 10:11:59 bazsi Exp $
+ * $Id: afstreams.c,v 1.4.2.5 2000/02/17 18:57:36 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -53,6 +53,7 @@
        (fd simple int)))
 */
 
+#if HAVE_DOOR_H
 static void do_kill_door(struct resource *r)
 {
 	CAST(door_fd, self, r);
@@ -69,6 +70,7 @@ static struct door_fd *make_door_fd(int fd)
 	f->fd = fd;
 	return f;
 }
+#endif
 
 /* CLASS:
    (class
@@ -203,8 +205,9 @@ static int do_init_afstreams_source(struct log_handler *c, struct syslog_conf *c
 	fd = open(self->name->data, O_RDONLY | O_NOCTTY | O_NONBLOCK);
 	if (fd != -1) {
 		struct strioctl ioc;
+#if HAVE_DOOR_H
 		struct stat st;
-		
+#endif	
 		memset(&ioc, 0, sizeof(ioc));
 		ioc.ic_cmd = I_CONSLOG;
 		if (ioctl(fd, I_STR, &ioc) < 0) { 
@@ -243,7 +246,7 @@ static int do_init_afstreams_source(struct log_handler *c, struct syslog_conf *c
 		}
 #else
                 if (self->door_name) {
-			close_fd(self->stream_fd);
+			close_fd(self->stream_fd, 0);
 			werror("sun-door support is not compiled in, door=%S\n", self->door_name);
 			return ST_FAIL | ST_QUIT;
                 }
