@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: cfgfile.c,v 1.22 1999/10/20 19:30:01 bazsi Exp $
+ * $Id: cfgfile.c,v 1.22.2.1 2000/02/17 18:57:36 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -141,6 +141,7 @@ static int do_destroy_config(struct syslog_conf *self)
 extern FILE *yyin;
 extern int yyparse();
 extern int yydebug;
+extern int linenum;
 
 struct syslog_conf *make_syslog_conf(const char *name, struct io_backend *backend)
 {
@@ -159,6 +160,7 @@ struct syslog_conf *make_syslog_conf(const char *name, struct io_backend *backen
 	self->time_reopen = 60;
 	self->log_fifo_size = 100;
 	if ((cfg = fopen(name, "r")) != NULL) {
+		linenum = 1;
 		yyin = cfg;
 		res = yyparse();
 		fclose(cfg);
