@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: main.c,v 1.20.2.1 1999/12/03 14:35:54 bazsi Exp $
+ * $Id: main.c,v 1.20.2.2 2000/02/17 18:57:36 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -165,7 +165,7 @@ void go_background()
 	
 	pid = fork();
 	if (pid == 0) {
-		int fd = open(pidfilename, O_CREAT | O_WRONLY | O_NOCTTY, 0666);
+		int fd = open(pidfilename, O_CREAT | O_WRONLY | O_NOCTTY | O_TRUNC, 0600);
 		if (fd != -1) {
 			struct ol_string *pid_s = c_format("%i", getpid());
 			write(fd, pid_s->data, pid_s->length);
